aboutsummaryrefslogtreecommitdiff
path: root/engines/gob/hotspots.h
diff options
context:
space:
mode:
authorSven Hesse2009-07-05 21:40:51 +0000
committerSven Hesse2009-07-05 21:40:51 +0000
commitedfaf7bc3c770c008be81f9ccb26835185d7d7d5 (patch)
tree6504408a41c6c7041e604aa6cff0f3c80a10f420 /engines/gob/hotspots.h
parent29e97533c1b884e231feb01ed99fd8ae17a3564d (diff)
downloadscummvm-rg350-edfaf7bc3c770c008be81f9ccb26835185d7d7d5.tar.gz
scummvm-rg350-edfaf7bc3c770c008be81f9ccb26835185d7d7d5.tar.bz2
scummvm-rg350-edfaf7bc3c770c008be81f9ccb26835185d7d7d5.zip
Added an enum for the hotspot states
svn-id: r42155
Diffstat (limited to 'engines/gob/hotspots.h')
-rw-r--r--engines/gob/hotspots.h23
1 files changed, 21 insertions, 2 deletions
diff --git a/engines/gob/hotspots.h b/engines/gob/hotspots.h
index 1801a10591..79a80526de 100644
--- a/engines/gob/hotspots.h
+++ b/engines/gob/hotspots.h
@@ -49,7 +49,18 @@ public:
kTypeInput3NoLeave = 7,
kTypeInput3Leave = 8,
kTypeInputFloatNoLeave = 9,
- kTypeInputFloatLeave = 10
+ kTypeInputFloatLeave = 10,
+ kTypeEnable2 = 11,
+ kTypeEnable1 = 12,
+ kTypeClickEnter = 21
+ };
+
+ enum State {
+ kStateFilledDisabled = 0xC,
+ kStateFilled = 0x8,
+ kStateDisabled = 0x4,
+ kStateType2 = 0x2,
+ kStateType1 = 0x1
};
Hotspots(GobEngine *vm);
@@ -68,7 +79,7 @@ public:
/** Push the current hotspots onto the stack.
*
* @param all 0: Don't push global ones; 1: Push all; 2: Push only the ones with the correct state
* @param force Force a push although _shouldPush is false
*/
void push(uint8 all, bool force = false);
@@ -115,12 +126,20 @@ private:
bool isInput() const;
bool isActiveInput() const;
+ bool isFilled() const;
+ bool isFilledEnabled() const;
+ bool isFilledNew() const;
+ bool isDisabled() const;
+
/** Are the specified coordinates in the hotspot? */
bool isIn(uint16 x, uint16 y) const;
/** Does the specified button trigger the hotspot? */
bool buttonMatch(MouseButtons button) const;
static uint8 getState(uint16 id);
+
+ void disable();
+ void enable();
};
struct StackEntry {
@@ -68,7 +79,7 @@ public:
/** Push the current hotspots onto the stack.
*
- * @param all 0: Don't push global ones; 1: Push all; 2: Push only the ones with the correct state
+ * @param all 0: Don't push global ones; 1: Push all; 2: Push only the disabled ones
* @param force Force a push although _shouldPush is false
*/